Indice — SoL 4, manuale utente

# Indice

A | B | C | D | F | G | I | L | M | P | R | S | T | U | V

## A

Arbitro Associazione Club Utenti | Avversario nei Doppi Avversario nei Singoli

## B

Board

## C

C/B C/M Campionati Gestione Campionato Inserimento e modifica Cannon | Club Gestione Inserimento e modifica Utenti Associazione Conferma Correzione concorrenti Tornei

## D

Dito | Duplicati Giocatori

## F

Fantasma | Federazioni nazionali Finire

## G

Gestione Campionati Club Giocatori Tornei Valutazioni Glicko | Giocatore Giocatori Duplicati Gestione Inserimento e modifica Valutazioni Giuria

## I

Imbucare Incontro Inserimento e modifica Campionato Club Giocatori Tornei Utenti Valutazioni Glicko

## L

Linee immaginarie

## M

Mano

## P

Pair Partita Pegno | Penalità Piazzare Premi finali

## R

Regina | Regole

## S

Shot Slam bianco | Slam nero Spaccata Spingere

## T

Thumbing Tiro Tiro corretto Tiro scorretto | Tornei Correzione concorrenti Gestione Inserimento e modifica Turno

## U

Utenti Associazione, Club Inserimento e modifica

## V

Valutazioni Giocatori | Valutazioni Glicko Gestione Inserimento e modifica